@@ -357,9 +357,10 @@ class Model:
         for name in self.variablenames:
             if 'tbl' in name:
                 n = 0
-                for tbl in data['table'].keys():
-                    if name == tbl:
-                        n += 1
+                for tbl in data['table']:
+                    for key in tbl:
+                        if name == key:
+                            n += 1
                 dict.update({name:[positions[name],n]})
 
         for key in dict:
@@ -367,16 +368,22 @@ class Model:
             tables.update({s:key})
         result = []
         for key in tables:
-            print(key, tables[key])
             result.append([int(key.split(':')[0]),int(key.split(':')[1])])
-        return result
+        for el in result:
+            for variable in self.__variables:
+                if variable.row >= int(el[0]):
+                    variable.row = variable.row + int(el[1])
+            for style in self.__styles:
+                if style.row >= int(el[0]):
+                    style.row = style.row + int(el[1])
+
+        return None
 
     def import_data(self, data):
         """
         Documentation
-        """
 
-        """
+
         for variable in self.variables:
             if variable.name in data:
                 variable.value = data[variable.name]
@@ -390,8 +397,7 @@ class Model:
                     if variable.name in data['table']:
 
                 for variable in self.variables:
-                    if variable.row >
-    """
+                    if variable.row >"""
         return None
 
     def past_in_worksheet(self,worksheet):
@@ -412,3 +418,4 @@ class Model:
             worksheet[style.name].alignment = copy(style.alignment)
         for merge in self.mergedcells:
             worksheet.merge_cells(merge)
+        return None
